@@ -93,6 +93,8 @@
 		'ssha512'=>'ssha512',
 		'sha256crypt'=>'sha256crypt',
 		'sha512crypt'=>'sha512crypt',
+		'argon2i'=>'argon2i',
+		'argon2id'=>'argon2id',
 	 )*/
 #  $config->custom->password['available_types'] = array(''=>'clear','md5'=>'md5');
 
